---
title: "Drivers of inequality Uganda"
author:
    - Marty Oehme
papersize: A4
geometry:
  - left=2cm
  - right=2.5cm
  - top=2.5cm
  - bottom=2.5cm
indent: true
linestretch: 1.25
fontfamily: lmodern
fontsize: 12
lang: en
bibliography: /home/marty/projects/jobs/afd/inputs/libraries/afd-dev-research.bib
csl: /home/marty/documents/library/academia/styles/APA-7.csl
output:
    pdf_document:
        latex_engine: xelatex
header-includes:
    - \usepackage{fvextra}
    - \DefineVerbatimEnvironment{Highlighting}{Verbatim}{breaklines,breakanywhere,commandchars=\\\{\}}
---

# Script

Summary:

-----
* Poverty and inequality in Uganda are at a fluctuating level in Uganda, with relative poverty staying roughly stable and inequality slowly trending upward.
* National poverty line set very low, potentially hiding additional households in states of deprivation and those in danger of reverting to poverty.
* Inequality, poverty and informal economy in close circular relation in Uganda, presenting a vicious circle for those captive within.
* Education levels of poor people are consistently low, with those of rural population more so.
* Inadequate access to clean water can exacerbate these inequalities, directly influencing food security, rural child education and gender inequalities.
* The district of Isingiro especially is dramatically below national average of clean water access, and in danger of exacerbation through climate change.
-----

<!-- intro/overall -->
Uganda generally has a degree of inequality that fluctuates but over time seems largely unchanged,
as does the share of people below its poverty line in recent years.
The overall level of welfare inequality in the country had a slight upward trend,
with a Gini coefficient of 0.36 calculated for the 1992/93 census and a World Bank calculation of 0.43 for the year 2019,
with the coefficient rising significantly in the years 2002/03 and 2009/10 during its fluctuation [@Lwanga-Ntale2014; @Atamanov2022].
However, the overall aggregation masks several important distinctions:
Rural inequality on the whole is lower than urban inequality, with Lwanga-Ntale [@Lwanga-Ntale2014] finding coefficients of 0.35 and 0.41 for 2012/13 respectively.
Additionally, he sees quintile inequalities primarily driven by the highest quintile (0.25) with the middle-incomes less affected (0.05-0.07),
also finding a significantly higher coefficient for the first quintile (0.14), however.
These inequality levels remain mostly unchanged from 2012/13 to 2019/20 but hide qualitative dimensions such as the shift out of a lower-income agricultural livelihood predominantly taking place amongst older men who have at least some level of formal education and are from already more well-off households [@Atamanov2022].

<!-- poverty -->
Atamanov et al. [-@Atamanov2022] go on to examine the share of people below the poverty line in Uganda:
around 30% of households are in a state of poverty in 2019/20,
which once again fluctuated but roughly reflects the share of 30.7% households in poverty in 2012/13.
Two surges in rural household poverty in 2012/2013 and 2016/17 can be linked to droughts in the country,
with an improvement in 2019/20 conversely being linked to favorable weather conditions.
<!-- TODO find citation or put Atamanov -->
Ssewanyana and Kasirye [-@Ssewanyana2012] find that in absolute terms poverty fell significantly (from 28.5% in 2005/06 to 23.9% in 2009/10) but there are clear relative regional differences emerging,
with Western Ugandan households increasing in poverty while Northern and Eastern households reduced their share of households below the poverty line.
Additionally they find, while transient poverty is more common than chronic poverty in Uganda,
nearly 10% of households continue to live in persistent or chronic poverty.
Lastly, for a long time it has been seen as an issue that Uganda puts its national poverty line too low with the line being put between 0.94 USD PPP and 1.07 USD PPP depending on the province (lower than the international live of 1.90 USD PPP),
while van de Ven [-@vandeVen2021] estimate a living income of around 3.82 USD PPP would be required for a national poverty line that meets basic human rights for a decent living.
<!-- TODO find a source for the national poverty line being too low (quant data is already in vandeVen2021) -->

<!-- endowment/assets: education, ..? -->
Esaku [-@Esaku2021; -@Esaku2021a] finds a somewhat circular driving relationship between Ugandan inequality, poverty and working in what calls the shadow economy:
inequality increases the size of the informal economy, as a large subsistence sector creates revenue tax shortfalls,
undermines the governments efforts to attain equitable income distributions in the economy and the creation of social safety nets for the poort, who, in turn,
have to turn to the informal economy to secure their livelihoods,
increasing its size both short- and long-term and feeding back into the cycle.
Cali [-@Cali2014] finds that, already, one of the primary determinants of income disparity in more trade-exposed markets of Uganda in the 1990s were the increasing education differences leading to more disparate wage premiums.
Additionally, slow structural change ---
further impeded by the onset of the COVID-19 pandemic, which pushed both urban and rural residents back into poverty ---
leaves a low-productivity agricultural sector which becomes,
in combination with a lack of education, the strongest predictor of poverty:
the poverty rate in households with an uneducated household head (17% of all households) is 48% (2019/20),
while already households with a household head possessing primary education (also 17% of all) nearly cuts this in half with 25% poverty rate (2019/20) [@Atamanov2022].
The World Bank [-@WorldBank2022] calculated a Learning Poverty Indicator for Uganda which finds that 82% of children at late primary age are not proficient in reading, 81% of children do not achieve minimum proficiency level in reading at the end of primary schooling, and 4% of primary school-aged children are not enrolled in school at all.
Datzberger [-@Datzberger2018] argues these problems primarily exist in Uganda due to choosing an approach to education that is primarily assimilation-based, that is, intended to effect change at the individual-level through fostering grassroots education throughout society at large,
instead of looking into more transformative policy approaches which would operate on a more systemic level,
removing oppressive structures of inequality in tandem with government institutions at multiple levels.

<!-- water access -->
Such personal circumstances as access to a timely education play decisive role in life and human capital development ---
circumstances to which decent housing as well as access to clean water are equally fundamental building blocks [@Atamanov2022].
In 1990 a policy initiative to shift from a supply-driven to a demand-driven model for rural drinking water provision was enacted which, over time,
improved rural safe water coverage slightly but also made operation and maintenance of improved water sources pose a challenge that could impede long-term access to safe water.
In the country, access to improved water sources rose from 44% in 1990 to 60% in 2004 and 66% in 2010 [@Naiga2015].
In 2019, access to improved sources of drinking water in the country is at a level of 87% in urban areas and 74% in rural areas, with relatively little inequality in rural regions between poor and non-poor households [@Atamanov2022].
Health care facilities in rural areas are generally well connected to improved sources with 94% of facilities having access to public stand posts, protected spring technology, deep boreholes and some to rain harvesting tanks, gravity flow schemes or groundwater-based pumped piped water supplies [@Mulogo2018].
Thus, individual households are generally less well connected than health care facilities,
and rural households in turn less well than urban households.

<!-- Isingiro district -->
The same study found for the Isingiro district in Western Uganda on the other hand, in 2010,
only 28% of households had access to improved water [@Mulogo2018].
<!-- TODO check validity -->
Naiga et al. [-@Naiga2015] investigated the characteristics of improved water access in the Isingiro district, finding that whereas the national average distance to travel for a water source is 0.2km in urban and 0.8km in rural locations, in Isingiro it is 1.5km,
and of the fewer existing improved water sources, only 53% were fully functional,
with 24% being only partly functional (having only low or intermittent yield) and 18% not being functional at all.
Additionally, they found blocked drainage channels in some of the sources which could in turn lead to a possible health risk due to contamination of the source.
Naiga [-@Naiga2018] sees some reasons for the low access to working improved water sources in the absence of many of the organizational characteristics prescribed by the design principles of its community-managed water infrastructure management ---
unclear social boundaries, missing collective-choice arrangements and a lack of sanctions or conflict resolution mechanisms ---
in other words, a policy failure resulting in lack of sufficient self-governance arrangements.

Such inequalities in water access often stand in direct relationship with other inequalities such as along gender, geographic or income dimensions,
with fetching water traditionally being a female care role, the cost of user fees to gain access to improved water being prohibitive to poorer households, while the remoteness of many households' location makes the trekk to the source more time-consuming and replacement parts for repairs difficult to source in an adequate time [@Naiga2015].

<!-- water access during extreme events -->
Looking into the effects of climate change and its accompanying increase in climate shock events, especially droughts, on such gender roles,
Nagasha et al. [-Nagasha2019] find that it gender roles adapt while gender inequalities tend to increase,
with men participating more in firewood collection and water fetching but generally focused on assuming a single reproductive role while women played multiple roles simultaneously.
Two effects they found of this exacerbation were the women often being forced to engage their children in work activities to manage the simultaneous workload, and women, due to their exclusion from landownership in the region, being brought further into a state of dependence and thus made even more vulnerable to future climate change effects.
Water supply use seems to experience little change during emergency situations, and people's willingness (or ability) to pay for water is also too small to maintain water revenue without addressing the disparity in socio-economic attributes of households [@Sempewo2021; @Sempewo2021a].
Taken together, this hints at one possibility of subsequent health disparity increases due to prior income inequalities and poverty during emergency situations such as climate shocks.

Access to water is also one of the primary reasons for both real and perceived food insecurity vulnerabilities, even more so during climate shocks.
In Uganda, Cooper and Wheeler [-@Cooper2016] investigate the vulnerability of rural farmers to climate events and find that, while most farmers implement anticipatory and livelihood coping responses (54.7%),
many responses only protect against very specific events (45.4%) and most had no response at all to coping with rainfall variability:
while farmers with more land, education, access to government extensions and non-farm livelihoods have more capacity to buffer the shock,
both wealthier farmers (droughts as highest perceived risk) and poor farmers (extreme rainfall as highest) perceive themselves most vulnerable to rainfall-based events.
In the Isingiro district, Twongyirwe et al. [-@Twongyirwe2019] find that most farmers (68.6%) perceive food insecurity as a problem with the overwhelming majority seeing droughts as the major contributory issue to this food insecurity (95.6%).
They also find that mainly higher-income and larger farms see it as less of a problem,
while 13% of all farmers report that they did not, or could not, do anything to respond to the drought effects.
Lastly, even for inhabitants of wetland areas, droughts can pose problems.
Yikii et al. [-@Yikii2017], looking at the prevalence and determining factors of food insecurity in wetland adjacent areas in the district, find that 93% of households within wetlands are already food insecure due to poverty, low levels of labor productivity and low levels of education,
which they argue would worsen in droughts unless the government finds ways of promoting food and nutrition education, alternative income generating activities, drought resistant crop varieties and ways of water conservation.

<!-- conclusion -->
Thus, while Uganda's poverty and inequality are trending towards drastically worsening over the last years,
hidden disparities bring its issues in focus once disaggregated:
Nationally, poverty is a looming transient affair for many households, more if increasing the country's very low national line of poverty.
Inequality derives itself partly from this poverty, making it necessary for many to accept informal work which, taken at large, in turn fosters further national inequality.
The role education plays in Uganda's allocation of poverty cannot be overstated, with especially many rural children not having adequate opportunity to access timely education.
This disparity could be exacerbated by poor quality access to clean water through improved water sources,
which in turn worsens food securities, retrenches gender role inequalities and precludes more children from their education.
In the district of Isingiro in West Uganda access to water is considerably below the national average,
with policy failures during implementation now leading to partly or non-functional water sources.
The problem runs danger of deteriorating with an increased amount of climate shocks such as droughts threatening to exacerbate existing inequalities and drive further households into poverty.

\pagebreak
## References
